Learn R Programming

mma (version 3.1-0)

print.mma: Print a mma object

Description

Print the estimation of mediation effects from an mma object.

Usage

"print"(x,...)

Arguments

x
a mma object created initially call to mma, boot.med.binx, or boot.med.contx.
...
other arguments passed to the print function.

Value

Return a LIST

References

Yu, Q., Fan, Y., and Wu, X. (2014) . "General Multiple Mediation Analysis With an Application to Explore Racial Disparity in Breast Cancer Survival," Journal of Biometrics & Biostatistics,5(2): 189.

See Also

"mma","boot.med"

Examples

Run this code
data("weight_behavior")
 x=weight_behavior[,2:14]
 y=weight_behavior[,15]
 temp.b.b.glm<-mma(x,y,pred=2,contmed=c(8:10,12:13),binmed=c(7,11),
   binref=c(1,1),catmed=6,catref=1,predref="M",alpha=0.4,alpha2=0.4, 
   jointm=NULL,margin=1, n=2,seed=sample(1:1000,1),nonlinear=FALSE,nu=0.001,
   D=3,n2=2)
 print(temp.b.b.glm)

Run the code above in your browser using DataLab